@@ -2,12 +2,13 @@ package Geo::Coder::Yahoo;
 use warnings;
 use strict;
 use Carp qw(croak);
+use Encode qw(decode);
 use URI;
 use URI::QueryParam;
 use LWP::UserAgent;
 use Yahoo::Search::XML;
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 
 my $ua;
@@ -47,7 +48,7 @@ sub geocode {
 
     for my $d (@$results) {
         for my $k (keys %$d) {
-            $d->{lc $k} = delete $d->{$k};
+            $d->{lc $k} = decode("utf-8", delete $d->{$k});
         }
     }
 
